@@ -1,7 +1,7 @@
 
 package Class::DBI::Lite;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 use strict;
 use warnings 'all';
@@ -44,16 +44,16 @@ my %Live_Objects = ( );
 #==============================================================================
 BEGIN
 {
-__PACKAGE__->mk_classdata('_table');
-__PACKAGE__->mk_classdata('_handles' => { });
-__PACKAGE__->mk_classdata('_dbh');
-__PACKAGE__->mk_classdata('_columns' => { });
-__PACKAGE__->mk_classdata('_dsn');
-__PACKAGE__->mk_classdata('_schema');
-__PACKAGE__->mk_classdata('_driver');
-__PACKAGE__->mk_classdata('_has_a_rels' => { });
-__PACKAGE__->mk_classdata('_has_many_rels' => { });
-__PACKAGE__->mk_classdata('_triggers' => { });
+  __PACKAGE__->mk_classdata('_table');
+  __PACKAGE__->mk_classdata('_handles' => { });
+  __PACKAGE__->mk_classdata('_dbh');
+  __PACKAGE__->mk_classdata('_columns' => { });
+  __PACKAGE__->mk_classdata('_dsn');
+  __PACKAGE__->mk_classdata('_schema');
+  __PACKAGE__->mk_classdata('_driver');
+  __PACKAGE__->mk_classdata('_has_a_rels' => { });
+  __PACKAGE__->mk_classdata('_has_many_rels' => { });
+  __PACKAGE__->mk_classdata('_triggers' => { });
 }
 
 
@@ -603,10 +603,11 @@ sub _call_triggers
   my ($s, $event) = @_;
   
   my $handlers = $s->_triggers->{ $s->table }->{ $event };
-  foreach(  @$handlers )
+  shift;shift;
+  foreach my $handler (  @$handlers )
   {
     eval {
-      $_->( $s );
+      $handler->( $s, @_ );
       1;
     } or confess $@;
   }# end foreach()
@@ -683,7 +684,7 @@ Class::DBI::Lite - Lightweight ORM for Perl
 B<**NOTE**:> This module is still under development.  It is likely to change
 in dramatic ways without any warning.
 
-As is, this module should 
+As is, this module should not (yet) be used in a production environment until after v1.000.
 
 =head1 SYNOPSIS
 
@@ -717,6 +718,20 @@ are not wanted.
 
 L<Class::DBI>
 
+=head1 TODO
+
+=over 4
+
+=item * Documentation
+
+=item * Near-100% code coverage
+
+=item * Thorough code profiling
+
+=item * Examples
+
+=back
+
 =head1 AUTHOR
 
 John Drago <jdrago_999@yahoo.com>.
